@@ -9,12 +9,12 @@
 # gsar@umich.edu
 #
 
-require 5.001;
+require 5.002;
 package MLDBM;
-$VERSION = $VERSION = '1.20';
+$VERSION = $VERSION = '1.21';
 
-require TieHash;
-@ISA = qw(TieHash);
+require Tie::Hash;
+@ISA = qw(Tie::Hash);
 
 use Data::Dumper;
 use Carp;
@@ -26,6 +26,13 @@ use Carp;
 #
 $UseDB = "SDBM_File";
 
+#
+# we prefer the faster XS solution if it exists
+# You can override this with the DumpMeth() method
+#
+$DumpMeth = (defined &Data::Dumper::Dumpxs) ? 'Dumpxs' : 'Dump';
+
+
 #
 # the magic string used to recognize MLDBM data
 # this has to be something unique since we try to store
@@ -48,6 +55,7 @@ sub TIEHASH {
   $s->{DBname} = $UseDB;
   $s->{DB} = $UseDB->TIEHASH(@_) 
     or carp "MLDBM error: Second level tie failed, \"$!\"" and return undef;
+  $s->{dumpmeth} = $DumpMeth;
   return bless $s, $c;
 }
 
@@ -71,9 +79,10 @@ sub FETCH {
 sub STORE {
   my($s, $k, $v) = @_;
   if (ref($v) or $v =~ m|^\Q$Key|o) {
+    my $dumpmeth = $s->{dumpmeth};
     local $Data::Dumper::Indent = 0;
     local $Data::Dumper::Purity = 1;
-    $v = $Key . Data::Dumper->Dump([$v], ['M']);
+    $v = $Key . Data::Dumper->$dumpmeth([$v], ['M']);
 #    print $v;
   }
   $s->{DB}->STORE($k, $v);
@@ -104,6 +113,11 @@ sub import {
   $Key = $key if defined $key and $key;
 }
 
+sub DumpMeth {
+  my ($s, $meth) = @_;
+  (ref $s and defined $meth) ? ($s->{dumpmeth} = $meth) : $s->{dumpmeth};
+}
+
 1;
 __END__
 
@@ -132,7 +146,7 @@ It requires the Data::Dumper package, available at any CPAN site.
 
 See the B<BUGS> section for important limitations.
 
-=head2 Configuration Variables
+=head2 Configuration Variables/Methods
 
 =over 4
 
@@ -150,6 +164,13 @@ Defaults to the magic string used to recognize MLDBM data. It is a six
 character wide, unique string. This is best left alone, unless you know
 what you're doing.
 
+=item $MLDBM::DumpMeth  I<or>  $I<OBJ>->DumpMeth(I<[METHNAME]>)
+
+This controls which of the two dumping methods available from C<Data::Dumper>
+are used.  By default, this is set to "Dumpxs", the faster of the two 
+methods, but only if MLDBM detects that "Dumpxs" is supported on your 
+platform.  Otherwise, defaults to the slower "Dump" method.
+
 =back
 
 =head1 EXAMPLE
@@ -203,7 +224,7 @@ this will NOT work properly:
 Instead, that must be written as:
 
     $tmp = $mldb{key};                # retrieve value
-    $tmp{subkey}[3] = 'stuff';
+    $tmp->{subkey}[3] = 'stuff';
     $mldb{key} = $tmp;                # store value
 
 This limitation exists because the perl TIEHASH interface currently has no
@@ -211,14 +232,10 @@ support for multidimensional ties.
 
 =item 2.
 
-This not as efficient as one would like.
-
-=item 3.
-
-The previous version was released along with the Data::Dumper package as an
-example.  If you got serious with that and have a DBM file from that
-version, you can do something like this to convert the old records to the
-new format:
+MLDBM was first released along with the Data::Dumper package as an 
+example.  If you got serious with that and have a DBM file from that 
+version, you can do something like this to convert the old records 
+to the new format:
 
     use MLDBM (DB_File);              # be sure it's the new MLDBM
     use Fcntl;
@@ -245,7 +262,7 @@ modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-Version 1.20    16 February 1996
+Version 1.21    9 April 1996
 
 =head1 SEE ALSO
 
